import sqlite3
import os


def create_connection(path: str, filename: str):
    """ create a database connection to a SQLite database """
    conn = None
    try:
        # Make the directory for the file to go into
        create_directory(path)

        print("Opening Database file and ensuring table integrity")
        conn = sqlite3.connect(path + filename)

        print("Database file open")
        # Execute creation scripts
        sql = open("scripts/create_tables.sql", "r");
        conn.executescript(sql.read())
        
        print("SQLite Version: " + sqlite3.version)
        print("Table creation complete")
    except sqlite3.Error as e:
        print(e)
    finally:
        if conn:
            conn.close()

# Ensure a directory is created given a path to it
def create_directory(dir: str):
    try:
        os.makedirs(dir)
    except FileExistsError:
        pass

if __name__ == '__main__':
    create_connection(r"./data/",  r"wmgzon.db")
